.SSresults: Computes additional results of the Kalman filter and smoother.
Description
Computes additional results of the Kalman filter and smoother.
Usage
.SSresults(out, model, prediction = FALSE)
Arguments
- out
The return object of the function KFS from the package KFAS.
- model
An object of class NAWRUmodel, TFPmodel, or KuttnerModel.
- prediction
Logical indicating whether out includes predictions.