Assigns the appropriate function and its input variables for the Gibbs procedure.
.assignGibbsFUN(
loc,
type,
trend,
cycle,
cubsAR,
cycleLag,
errorARMA,
exoNames = NULL
)A data frame containing information on each involved parameter, for instance its corresponding system matrix, variable names, and parameter restrictions.
A character string specifying the type of the Phillip's curve.
type = "TKP" denotes the traditional Keynesian Phillip's curve and
type = "NKP" the New Keynesian Phillip's curve, see details. The default is
type = "TKP".
A character string specifying the trend model. trend = "RW1" denotes
a first order random walk, trend = "RW2" a second order random walk (local linear
trend) and trend = "DT" a damped trend model. The default is trend = "DT".
A character string specifying the cycle model. cycle = "AR1" denotes
an AR(1) process, cycle = "AR2" an AR(2) process, cycle = "RAR2" a
reparametrized AR(2) process. The default is cycle = "AR2".
A non-negative integer specifying the maximum CUBS lag that is included
in the CUBS equation. The default is cubsAR = 0, see details.
A non-negative integer specifying the maximum cycle lag that is included
in the CUBD equation. The default is cycleLag = 0, see details.
A vector with non-negative integers specifying the AR and MA degree of the error term in the second observation equation.
A character vector containing the names of the exogenous variables.