.BayesFitTFP and .BayesFitNAWRU for
consistency.Checks the input parameters of .BayesFitTFP and .BayesFitNAWRU for
consistency.
.checkBayesInput(
model,
type,
prior = NULL,
R = NULL,
burnin = NULL,
thin = NULL,
HPDIprob = NULL,
FUN = NULL,
MLEfit = NULL
)An object of class TFPmodel.
A character specifying whether a "nawru" or "tfp" model should be checked.
A list of matrices with parameters for the prior distribution and box
constraints. By default, prior is initialized by initializePrior(model).
See details. Only used if method = "bayesian".
An integer specifying the number of MCMC draws. The default is R = 10000.
Only used if method = "bayesian".
An integer specifying the burn-in phase of the MCMC chain. The default is
burnin = ceiling(R / 10). Only used if method = "bayesian".
An integer specifying the thinning interval between consecutive draws. The
default is thin = 1, implying that no draws are dopped. For thin = 2,
every second draw is dropped and so on. Only used if method = "bayesian".
A numeric in the interval (0,1) specifying the target probability
of the highest posterior density intervals. The default is HPDIprob = 0.9. Only
used if method = "bayesian".
A function to be used to compute estimates from the posterior distribution.
Possible options are "mean" and "median". The default is FUN = "mean".
Only used if method = "bayesian".
(Optional) An object of class TFPfit which is used for
initialization. Only used if method = "bayesian".