cubs for consistency and validity.Checks the input variables for the procedure cubs for consistency and validity.
.checkCubs(tsCU, tsVA, lambda, frequency)A multiple time series containing three survey time series, the first element needs to be capacity utilization in industry, see details. Alternatively, a list of time series can be supplied.
A multiple time series containing three value added series that correspond to
tsCU. Alternatively, a list of time series can be supplied.
The smoothing parameter for the application of the HP filter (see details).
If not supplied, lambda = 6.25 is used for yearly data and lambda = 1600
for quarterly data.
The frequency of the computed cubs indicator. Possible entries are
frequency = 1 (annual), frequency = 4 (quarterly). The default is
frequency = 1.