KuttnerModel for consistency and validity.Checks the input variables for the procedure KuttnerModel for consistency and validity.
.checkKuttner(
tsl,
trend,
cycle,
cycleLag,
errorARMA,
start,
end,
anchor,
anchor.h
)A list of time series objects, see details.
A character string specifying the trend model. trend = "RW1" denotes
a first order random walk, trend = "RW2" a second order random walk (local linear
trend) and trend = "DT" a damped trend model. The default is trend = "RW1".
A character string specifying the cycle model. cycle = "AR1" denotes
an AR(1) process, cycle = "AR2" an AR(2) process. The default is
cycle = "AR2".
A non-negative integer specifying the maximum cycle lag that is included
in the inflation equation. The default is cycleLag = 0, see details.
A vector with non-negative integers specifying the AR and MA degree of the error term in the inflation equation.
(Optional) Start vector for the estimation, e.g. c(1980, 1).
(Optional) End vector for the estimation, e.g. c(2020, 1).
(Optional) Anchor value for the logarithm of trend gdp.
(Optional) Anchor horizon in the frequency of the given time series.