NAWRUmodel for consistency and
validity.Checks the input variables for the procedure NAWRUmodel for consistency and
validity.
.checkNawru(
tsl,
trend,
cycle,
type,
cycleLag,
errorARMA,
exoNames,
exoType,
start,
end,
anchor,
anchor.h
)A list of time series objects, see details.
A character string specifying the trend model. trend = "RW1" denotes
a first order random walk, trend = "RW2" a second order random walk (local linear
trend) and trend = "DT" a damped trend model. The default is trend = "RW2".
A character string specifying the cycle model. cycle = "AR1" denotes
an AR(1) process, cycle = "AR2" an AR(2) process. The default is
cycle = "AR2".
A character string specifying the type of the Phillip's curve.
type = "TKP" denotes the traditional Keynesian Phillip's curve and
type = "NKP" the New Keynesian Phillip's curve, see details. The default is
type = "TKP".
A vector specifying the cycle lags that are included in the Phillip's
curve. The default is cycleLag = 0, see details.
A vector with non-negative integers specifying the AR and MA degree of the error term in the Phillip's curve equation.
A character vector containing the names of the exogenous variables.
An optional n x m x 2 array specifying the possible difference
and lag transformation for the variables. exoType can be initialized using the
function inizializeExo. The column names give the variable names.
exoType[, , 1] contains the difference transformations and exoType[, , 2]
the subsequent lag transformations, see details.
(Optional) Start vector for the estimation, e.g. c(1980, 1).
(Optional) End vector for the estimation, e.g. c(2020, 1).
(Optional) Anchor value for the unemployment rate.
(Optional) Anchor horizon in the frequency of the given time series.