TFPmodel for consistency and validity.Checks the input variables for the procedure TFPmodel for consistency and validity.
.checkTfp(
tsl,
trend,
cycle,
cycleLag,
cubsAR,
errorARMA,
start,
end,
anchor,
anchor.h
)A list of time series objects, see details.
A character string specifying the trend model. trend = "RW1" denotes
a first order random walk, trend = "RW2" a second order random walk (local linear
trend) and trend = "DT" a damped trend model. The default is trend = "DT".
A character string specifying the cycle model. cycle = "AR1" denotes
an AR(1) process, cycle = "AR2" an AR(2) process, cycle = "RAR2" a
reparametrized AR(2) process. The default is cycle = "AR2".
A non-negative integer specifying the maximum cycle lag that is included
in the CUBD equation. The default is cycleLag = 0, see details.
A non-negative integer specifying the maximum CUBS lag that is included
in the CUBS equation. The default is cubsAR = 0, see details.
A vector with non-negative integers specifying the AR and MA degree of the error term in the CUBS equation.
(Optional) Start vector for the estimation, e.g. c(1980, 1).
(Optional) End vector for the estimation, e.g. c(2020, 1).
(Optional) Snchor value for the log of the TFP trend.
(Optional) Anchor horizon in the frequency of the given time series.