Computes confidence interval of Inverse Gamma distributed variable with given mean and standard deviation.
.intervalIGamma(mu, sd, qlower = 0.025, qupper = 1 - qlower)A 2 x k matrix containing the lower and upper bounds of the intervals.
A k x 1 vector of means.
A k x 1 vector of standard deviations.
A k x 1 vector of lower quantiles.
A k x 1 vector of upper quantiles.