NAWRUmodel or
TFPmodel.Updates the parameter constraints for on object of class NAWRUmodel or
TFPmodel.
.updateParConstraints(model, parRestr)The same model with updated list item loc.
A model of class NAWRUmodel or TFPmodel.
A list of matrices containing the parameter restrictions for the cycle,
trend, and the Phillip's curve. Each matrix contains the lower and upper bound of the
involved parameters. NA implies that no restriction is present. Autoregressive
parameters are automatically restricted to the stationary region unless box constraints
are specified. By default, parRestr is initialized by the function
initializeRestr(model). Only used if method = "MLE".